\name{ePubWU_theses}
\alias{ePubWU_theses}
\encoding{UTF-8}
\docType{data}
\title{ePubWU Theses Dublin Core Metadata}
\description{
  Dublin Core metadata for doctoral theses published in ePubWU, the
  online publishing platform for research related documents of WU
  (Wirtschaftsuniversität Wien).
}
\usage{
data("ePubWU_theses")
}
\format{
  A list matrix of character vectors, with rows corresponding to theses
  and the 15 columns giving the respective Dublin Core elements
  (variables).

  Variables \code{author}, \code{title}, and \code{description} give the
  author, title and abstract of the thesis, respectively.  Finally,
  \code{subject} gives keywords.
}
\details{
  Metadata were obtained from the theses set (\samp{Type = Thesis}) of
  the ePubWU OAI repository at \url{https://epub.wu.ac.at/cgi/oai2} via
  package \pkg{OAIHarvester}
  (\url{https://CRAN.R-project.org/package=OAIHarvester}).
  Information about missing abstracts was standardized, and the subject
  elements were split to give the individual keywords.
  
  See the documentation of package \pkg{OAIHarvester} for more
  information on Dublin Core and OAI, and
  \url{https://epub.wu.ac.at/} for information about ePubWU.
}
\examples{
data("ePubWU_theses")
## Inspect the first records:
head(ePubWU_theses)
## Number of theses by year:
yr <- sub("-.*", "", unlist(ePubWU_theses[, "date"]))
table(yr)
## Frequent topics:
head(sort(table(unlist(ePubWU_theses[, "subject"])), decreasing = TRUE))
}
\keyword{datasets}
